{% extends "base.html" %}

{% block announce %}
<div class="announce-wrapper">
  <div id="announce-left">
    <div class="item">
      <a class="announce-link" href="https://fastapicloud.com" target="_blank">
        <span class="twemoji">
          {% include ".icons/material/cloud-arrow-up.svg" %}
        </span> Join the <strong>FastAPI Cloud</strong> waiting list 🚀
      </a>
    </div>
    <div class="item">
      <a class="announce-link" href="https://x.com/fastapi" target="_blank">
        <span class="twemoji">
          {% include ".icons/fontawesome/brands/x-twitter.svg" %}
        </span> Follow <strong>@fastapi</strong> on <strong>X (Twitter)</strong> to stay updated
      </a>
    </div>
    <div class="item">
      <a class="announce-link" href="https://www.linkedin.com/company/fastapi" target="_blank">
        <span class="twemoji linkedin">
          {% include ".icons/fontawesome/brands/linkedin.svg" %}
        </span> Follow <strong>FastAPI</strong> on <strong>LinkedIn</strong> to stay updated
      </a>
    </div>
    <div class="item">
      <a class="announce-link" href="https://fastapi.tiangolo.com/newsletter/">
        <span class="twemoji">
          {% include ".icons/material/email.svg" %}
        </span> Subscribe to the <strong>FastAPI and friends</strong> newsletter 🎉
      </a>
    </div>
  </div>
  <div id="announce-right" style="position: relative;">
    <div class="item">
      <a title="BlockBee Cryptocurrency Payment Gateway" style="display: block; position: relative;" href="https://blockbee.io?ref=fastapi" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/blockbee-banner.png" />
      </a>
    </div>
    <div class="item">
      <a title="Scalar: Beautiful Open-Source API References from Swagger/OpenAPI files" style="display: block; position: relative;" href="https://github.com/scalar/scalar/?utm_source=fastapi&utm_medium=website&utm_campaign=top-banner" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/scalar-banner.svg" />
      </a>
    </div>
    <div class="item">
      <a title="Auth, user management and more for your B2B product" style="display: block; position: relative;" href="https://www.propelauth.com/?utm_source=fastapi&utm_campaign=1223&utm_medium=topbanner" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/propelauth-banner.png" />
      </a>
    </div>
    <div class="item">
      <a title="Zuplo: Scale, Protect, Document, and Monetize your FastAPI" style="display: block; position: relative;" href="https://zuplo.link/fastapi-web" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/zuplo-banner.png" />
      </a>
    </div>
    <div class="item">
      <a title="liblab - Generate SDKs from FastAPI" style="display: block; position: relative;" href="https://liblab.com?utm_source=fastapi" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/liblab-banner.png" />
      </a>
    </div>
    <div class="item">
      <a title="Deploy & scale any full-stack web app on Render. Focus on building apps, not infra." style="display: block; position: relative;" href="https://docs.render.com/deploy-fastapi?utm_source=deploydoc&utm_medium=referral&utm_campaign=fastapi" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/render-banner.svg" />
      </a>
    </div>
    <div class="item">
      <a title="Cut Code Review Time & Bugs in Half with CodeRabbit" style="display: block; position: relative;" href="https://www.coderabbit.ai/?utm_source=fastapi&utm_medium=banner&utm_campaign=fastapi" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/coderabbit-banner.png" />
      </a>
    </div>
    <div class="item">
      <a title="Making Retail Purchases Actionable for Brands and Developers" style="display: block; position: relative;" href="https://subtotal.com/?utm_source=fastapi&utm_medium=sponsorship&utm_campaign=open-source" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/subtotal-banner.svg" />
      </a>
    </div>
    <div class="item">
      <a title="Deploy enterprise applications at startup speed" style="display: block; position: relative;" href="https://docs.railway.com/guides/fastapi?utm_medium=integration&utm_source=docs&utm_campaign=fastapi" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/railway-banner.png" />
      </a>
    </div>
    <div class="item">
      <a title="SerpApi: Web Search API" style="display: block; position: relative;" href="https://serpapi.com/?utm_source=fastapi_website" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/serpapi-banner.png" />
      </a>
    </div>
    <div class="item">
      <a title="Greptile: The AI Code Reviewer" style="display: block; position: relative;" href="https://www.greptile.com/?utm_source=fastapi&utm_medium=sponsorship&utm_campaign=fastapi_sponsor_page" target="_blank">
        <span class="sponsor-badge">sponsor</span>
        <img class="sponsor-image" src="/img/sponsors/greptile-banner.png" />
      </a>
    </div>
  </div>
</div>
{% endblock %}
